@@ -117,7 +117,7 @@ class DedupStore:
             return False
 
 
-def _http_post_json(url: str, data: Dict[str, Any], timeout: float = 2.0, headers: Optional[Dict[str, str]] = None) -> tuple[int, str]:
+def _http_post_json(url: str, data: Any, timeout: float = 2.0, headers: Optional[Dict[str, str]] = None) -> tuple[int, str]:
     req = urllib.request.Request(url, method="POST")
     body = json.dumps(data).encode("utf-8")
     req.add_header("Content-Type", "application/json")
@@ -297,19 +297,19 @@ class LocalBridgeAddon:
             pass
         return True
 
-    def _get_req_header(self, flow: "http.HTTPFlow", name: str) -> Optional[str]:  # type: ignore
+    def _get_req_header(self, flow: Any, name: str) -> Optional[str]:
         try:
             return flow.request.headers.get(name) if (flow and flow.request) else None
         except Exception:
             return None
 
-    def _get_resp_header(self, flow: "http.HTTPFlow", name: str) -> Optional[str]:  # type: ignore
+    def _get_resp_header(self, flow: Any, name: str) -> Optional[str]:
         try:
             return flow.response.headers.get(name) if (flow and flow.response) else None
         except Exception:
             return None
 
-    def _is_api_like(self, flow: "http.HTTPFlow", method: str, url: str) -> bool:  # type: ignore
+    def _is_api_like(self, flow: Any, method: str, url: str) -> bool:
         xr = (self._get_req_header(flow, "x-requested-with") or "").lower() == "xmlhttprequest"
         sfm = (self._get_req_header(flow, "sec-fetch-mode") or "").lower()
         sfd = (self._get_req_header(flow, "sec-fetch-dest") or "").lower()
@@ -353,7 +353,7 @@ class LocalBridgeAddon:
             return True
         return False
 
-    def _should_keep(self, flow: "http.HTTPFlow", method: str, url: str) -> bool:  # type: ignore
+    def _should_keep(self, flow: Any, method: str, url: str) -> bool:
         # 先按“过滤判定”剔除静态，再按“保留判定”兜底保留 API；若两者均不命中则丢弃
         ct = self._get_resp_header(flow, "content-type")
         is_static = self._is_static_by_url(url) or self._is_static_by_ct(ct)
@@ -421,7 +421,7 @@ class LocalBridgeAddon:
         except Exception:
             return ""
 
-    def _norm_body_hash(self, flow: "http.HTTPFlow") -> str:  # type: ignore
+    def _norm_body_hash(self, flow: Any) -> str:
         try:
             req = flow.request if (flow and flow.request) else None
             if not req:
@@ -445,7 +445,7 @@ class LocalBridgeAddon:
         except Exception:
             return self._hash_bytes(b"")
 
-    def _make_signature_key(self, flow: "http.HTTPFlow", method: str, url: str) -> tuple[str, str, str]:  # key, METHOD, path
+    def _make_signature_key(self, flow: Any, method: str, url: str) -> tuple[str, str, str]:  # key, METHOD, path
         try:
             parts = urlsplit(url or "")
             host = parts.netloc.lower()
@@ -472,7 +472,7 @@ class LocalBridgeAddon:
             return hashlib.sha256(base.encode("utf-8")).hexdigest(), (method or "").upper(), "/"
 
     # mitmproxy hook: called when a server response has been received
-    def response(self, flow: "http.HTTPFlow") -> None:  # type: ignore
+    def response(self, flow: Any) -> None:
         try:
             flow_id = str(getattr(flow, "id", "")) or self._gen_flow_id()
             method = (flow.request.method if flow and flow.request else None) or ""
@@ -554,17 +554,75 @@ class LocalBridgeAddon:
                     print(f"[local_bridge] debug: dedup error: {_e}")
 
             # 1) local notify: flow (non-blocking)
-            self.notifier.notify(
-                "flow",
-                {
-                    "flowId": flow_id,
-                    "method": method,
-                    "url": url,
-                    "status": status if status is not None else -1,
-                    "sessionId": self.session_id,
-                    "ts": ts_ms,
-                },
-            )
+            # 改为携带 headers 与文本体，方便本地服务统一“文本优先”并写入数据库
+            # 注意：保持非阻塞，避免影响 mitmproxy 主循环
+            try:
+                # 先构造 headers
+                simple_req_headers: Dict[str, str] = {}
+                simple_resp_headers: Dict[str, str] = {}
+                try:
+                    if flow and flow.request and getattr(flow.request, "headers", None):
+                        # 使用单值映射，避免依赖下方 _headers_to_dict 的局部定义顺序
+                        for k in flow.request.headers.keys():
+                            simple_req_headers[k] = flow.request.headers.get(k)
+                except Exception:
+                    simple_req_headers = {}
+                try:
+                    if flow and flow.response and getattr(flow.response, "headers", None):
+                        for k in flow.response.headers.keys():
+                            simple_resp_headers[k] = flow.response.headers.get(k)
+                except Exception:
+                    simple_resp_headers = {}
+
+                # 文本体优先：尝试直接获取文本；失败时回退到原始字节的 UTF-8 忽略错误解码
+                def _safe_get_text_req() -> str:
+                    try:
+                        if flow and flow.request:
+                            txt = flow.request.get_text(strict=False)
+                            if isinstance(txt, str) and txt:
+                                return txt
+                            raw = getattr(flow.request, "raw_content", None)
+                            if isinstance(raw, (bytes, bytearray)):
+                                return raw.decode("utf-8", errors="ignore")
+                    except Exception:
+                        pass
+                    return ""
+
+                def _safe_get_text_resp() -> str:
+                    try:
+                        if flow and flow.response:
+                            txt = flow.response.get_text(strict=False)
+                            if isinstance(txt, str) and txt:
+                                return txt
+                            raw = getattr(flow.response, "raw_content", None)
+                            if isinstance(raw, (bytes, bytearray)):
+                                return raw.decode("utf-8", errors="ignore")
+                    except Exception:
+                        pass
+                    return ""
+
+                req_txt = _safe_get_text_req()
+                resp_txt = _safe_get_text_resp()
+
+                self.notifier.notify(
+                    "flow",
+                    {
+                        "flowId": flow_id,
+                        "method": method,
+                        "url": url,
+                        "status": status if status is not None else -1,
+                        "sessionId": self.session_id,
+                        "ts": ts_ms,
+                        # 额外增强字段：headers 与文本体
+                        "requestHeaders": simple_req_headers,
+                        "responseHeaders": simple_resp_headers,
+                        "requestBody": req_txt,
+                        "responseBody": resp_txt,
+                    },
+                )
+            except Exception as _e:
+                # 不影响后续远端上传与 flow_ext 通知
+                print(f"[local_bridge] debug: flow notify error: {_e}")
 
             # 2) optional remote upload (extended dto for headers/bodies/query etc.)
             # startedAt
@@ -674,6 +732,8 @@ class LocalBridgeAddon:
             except Exception:
                 resp_b64 = ""
 
+            # 1.1) 同步增强：在构造 dto 之前，确保 flow 已携带文本体（上方已处理），此处不再重复
+
             # meta (add identity hints if available)
             meta_obj: Dict[str, Any] = {
                 "addon": "local_bridge_addon",
@@ -728,6 +788,33 @@ class LocalBridgeAddon:
                 "meta": meta_obj,
             }
 
+            # 1.5) local notify: flow_ext (non-blocking, fire-and-forget)
+            # TODO: add switch and rate-limit for 'flow_ext' in future (do not implement now)
+            try:
+                payload_ext: Dict[str, Any] = {
+                    "flowId": flow_id,
+                    "method": method,
+                    "url": url,
+                    "status": status if status is not None else -1,
+                    "sessionId": self.session_id,
+                    "ts": ts_ms,
+                    "durationMs": duration_ms if duration_ms is not None else 0,
+                    "startedAt": started_at or datetime.now().isoformat(timespec="seconds"),
+                    "query": query_json,
+                    "requestHeaders": req_headers,
+                    "responseHeaders": resp_headers,
+                    "requestBodyBase64": req_b64,
+                    "responseBodyBase64": resp_b64,
+                }
+                self.notifier.notify("flow_ext", payload_ext)
+                try:
+                    print(f"[local_bridge] notify flow_ext: req_b64_len={len(req_b64)} resp_b64_len={len(resp_b64)} hdrs=({len(req_headers)},{len(resp_headers)})")
+                except Exception:
+                    pass
+            except Exception as _e:
+                # never break flow; just debug summary
+                print(f"[local_bridge] debug: flow_ext notify error: {_e}")
+
             def _on_done(fid: str, uploaded: bool, error: Optional[str]):
                 # local notify: upload result
                 self.notifier.notify(
