@@ -1,9 +1,27 @@
 from __future__ import annotations
 
 from typing import Any, Dict, Optional
-from fastapi import FastAPI, Request, HTTPException
-from fastapi.middleware.cors import CORSMiddleware
-from starlette.responses import StreamingResponse
+import importlib
+from typing import TYPE_CHECKING
+try:
+    _fastapi = importlib.import_module("fastapi")
+    FastAPI = getattr(_fastapi, "FastAPI")
+    Request = getattr(_fastapi, "Request")
+    HTTPException = getattr(_fastapi, "HTTPException")
+except Exception:
+    FastAPI = None
+    class Request: ...
+    class HTTPException(Exception): ...
+try:
+    _cors_mod = importlib.import_module("fastapi.middleware.cors")
+    CORSMiddleware = getattr(_cors_mod, "CORSMiddleware")
+except Exception:
+    class CORSMiddleware: ...
+try:
+    _starlette_responses = importlib.import_module("starlette.responses")
+    StreamingResponse = getattr(_starlette_responses, "StreamingResponse")
+except Exception:
+    class StreamingResponse: ...
 import asyncio
 import shutil
 import platform
@@ -15,6 +33,7 @@ from . import proxy_macos
 from .config import load_config
 from .backend_client import BackendAPIError, build_backend_api_from_context
 from .packaging_utils import find_mitmdump_executable
+from .realtime_manager import fix_headers_field, map_notify_to_item
 
 # added: logging & forwarding deps
 import os
@@ -25,6 +44,17 @@ from urllib import request as _urlreq, error as _urlerr
 
 app = FastAPI(title="sensitive-check-local", version=__version__)
 
+# Import and register realtime routes from server.py
+try:
+    from . import server
+    # Register realtime routes from server.py to the main app
+    for route in server.app.routes:
+        if hasattr(route, 'path') and route.path.startswith('/local/realtime'):
+            app.router.routes.append(route)
+    print("Successfully registered realtime routes from server.py")
+except Exception as e:
+    print(f"Failed to register realtime routes: {e}")
+
 # In-memory snapshot for macOS system proxy to allow rollback on /stop or failure during /start
 _proxy_snapshot: Dict[str, Any] | None = None
 _proxy_services: list[str] | None = None
@@ -80,7 +110,7 @@ def _status_payload(state: Dict[str, Any]) -> Dict[str, Any]:
         "sessionId": state.get("sessionId"),
         "lastError": state.get("lastError"),
         "proxyEnabled": bool(state.get("proxyEnabled", False)),
-        "pendingCount": int(extra.get("pendingCount", 0)),
+        "queueSize": int(extra.get("queueSize", 0)),
         "lastEventTs": extra.get("lastEventTs"),
         # optional but useful for debugging
         "dedupEnabled": bool(state.get("dedupEnabled", False)),
@@ -169,8 +199,8 @@ async def _forward_ingest(body: dict):
             "url": body.get("url") or body.get("requestUrl") or "http://aqapi.jdtest.local/",
             "responseStatus": body.get("responseStatus") or body.get("status") or 200,
             "durationMs": body.get("durationMs") or 0,
-            "requestHeaders": body.get("requestHeaders") or {},
-            "responseHeaders": body.get("responseHeaders") or {},
+            "requestHeaders": fix_headers_field(body.get("request", {}).get("headers") or body.get("requestHeaders")),
+            "responseHeaders": fix_headers_field(body.get("response", {}).get("headers") or body.get("responseHeaders")),
             "requestBodyBase64": body.get("requestBodyBase64") or "",
             "responseBodyBase64": body.get("responseBodyBase64") or "",
             "meta": body.get("meta") or {},
@@ -219,7 +249,50 @@ async def notify(req: Request) -> Dict[str, Any]:
     except Exception:
         body = {}
 
-    # logging for visibility
+    # 过滤目标通知：仅处理 type == 'flow'（不再支持 flow_ext）
+    try:
+        type_str = str(body.get("type") or "").strip().lower()
+    except Exception:
+        type_str = ""
+    if type_str != "flow":
+        try:
+            _logger.info("[local-notify] skipped type=%s", type_str or "unknown")
+        except Exception:
+            pass
+        return {"ok": True, "message": "skipped"}
+    
+    # 一次性内判（one-shot）：在入口消费并跳过，避免丢头时重复入队
+    try:
+        from .realtime_queue import get_realtime_queue
+        queue = get_realtime_queue()
+    except Exception:
+        queue = None
+    try:
+        # 从 body 或 body.payload 提取 URL，解析为 domain|path
+        payload_obj = (body.get("payload") or {}) if isinstance(body.get("payload"), dict) else {}
+        url_raw = body.get("url") or body.get("requestUrl") or payload_obj.get("url") or payload_obj.get("requestUrl") or ""
+        from urllib.parse import urlparse
+        p = urlparse(str(url_raw) or "")
+        dom = (p.netloc.split(":")[0] if ":" in (p.netloc or "") else (p.netloc or "")).lower().strip()
+        pth = p.path or "/"
+        key = f"{dom}|{pth}"
+        pending_key = getattr(queue, "_pending_internal_key", None) if queue else None
+        if queue and queue.is_running() and pending_key and key == pending_key:
+            # 命中一次性标记：立即消费并跳过入队
+            try:
+                queue._pending_internal_key = None
+            except Exception:
+                pass
+            try:
+                _logger.info("[local-notify] one_shot_filtered domain=%s path=%s", dom, pth)
+            except Exception:
+                pass
+            return {"ok": True, "message": "skipped"}
+    except Exception:
+        # 任何异常均不影响原有逻辑，继续执行
+        pass
+
+    # 可见性日志（降敏）
     try:
         keys = list(body.keys())
         preview = _truncate(json.dumps(body) if isinstance(body, dict) else str(body), _FORWARD_LOG_BODY_MAX)
@@ -227,11 +300,56 @@ async def notify(req: Request) -> Dict[str, Any]:
     except Exception:
         pass
 
-    # Broadcast first, then apply event to counters
+    # 广播事件（用于前端展示），并更新计数
     await events.broadcast(body)
     events.apply_event(body)
 
-    # forward to backend (best-effort, async)
+    # 使用标准映射并入队（环形缓冲）
+    try:
+        from .realtime_queue import get_realtime_queue
+
+        queue = get_realtime_queue()
+        if queue and queue.is_running():
+            item = map_notify_to_item(body)
+
+            # 入队前域名过滤：仅接受目标域名
+            accept = True
+            try:
+                if hasattr(queue, "should_accept_item"):
+                    accept = bool(queue.should_accept_item(item))
+            except Exception:
+                accept = False
+
+            if not accept:
+                try:
+                    _logger.info(
+                        "[local-notify] skipped non-target domain: %s (url=%s, accepted_domains=%s)",
+                        item.get("domain"),
+                        item.get("url"),
+                        queue.get_accepted_domains() if hasattr(queue, "get_accepted_domains") else "unknown",
+                    )
+                except Exception:
+                    pass
+            else:
+                await queue.enqueue(item)
+                try:
+                    preview_obj = {
+                        "flowId": item.get("flowId"),
+                        "method": item.get("method"),
+                        "domain": item.get("domain"),
+                        "path": item.get("path"),
+                        "occurMs": item.get("occurMs"),
+                    }
+                    _logger.info("[local-notify] enqueued preview=%s", json.dumps(preview_obj, ensure_ascii=False))
+                except Exception:
+                    pass
+    except Exception as e:
+        try:
+            _logger.warning("[local-notify] realtime enqueue failed: %s", e)
+        except Exception:
+            pass
+
+    # 异步转发给后端（最佳努力）
     try:
         asyncio.create_task(_forward_ingest(body))
     except Exception:
@@ -293,11 +411,15 @@ async def start(req: Request) -> Dict[str, Any]:
             "proxyEnabled": False,
         }
 
-    # export identity to API process env for forwarding header injection
+    # export identity and ingest key to API process env for forwarding header injection
     try:
         os.environ["USER_ID"] = str(user_id)
         os.environ["PROJECT_ID"] = str(project_id)
         os.environ["TASK_ID"] = str(task_id)
+        # 同步将 INGEST_KEY 注入当前进程环境，供 _forward_ingest 使用
+        ingest_key = body.get("ingestKey") or merged_cfg.get("ingest_key")
+        if ingest_key is not None and str(ingest_key).strip() != "":
+            os.environ["INGEST_KEY"] = str(ingest_key)
     except Exception:
         pass
     ingest_url_present = bool(body.get("ingestUrl") or merged_cfg.get("ingest_url"))
@@ -439,6 +561,15 @@ async def start(req: Request) -> Dict[str, Any]:
         if hasattr(process, "set_last_error"):
             process.set_last_error(None)
 
+    # 设置全局活动模式：仅在未设置时设为数据传输检测，避免覆盖实时检测模式
+    try:
+        from . import server
+        # 如果当前模式不是 realtime，则设置为 ingest
+        if server._activity_mode != "realtime":
+            server._activity_mode = "ingest"
+    except Exception:
+        pass
+    
     return {
         "ok": True,
         "sessionId": res.get("sessionId"),
@@ -467,6 +598,14 @@ async def stop() -> Dict[str, Any]:
     _proxy_services = None
     _proxy_enabled = False
     process.set_proxy_enabled(False)
+    
+    # 清理全局活动模式
+    try:
+        from . import server
+        server._activity_mode = None
+    except Exception:
+        pass
+    
     return {"ok": True, "running": False, "proxyEnabled": False}
 # ============================================================================
 # 越权测试相关接口（新增）
