@@ -13,7 +13,14 @@ from typing import Any, Dict, Optional
 
 import yaml
 
-DEFAULTS: Dict[str, Any] = {}
+DEFAULTS: Dict[str, Any] = {
+    "realtime": {
+        "batchIntervalSec": 10,
+        "batchSize": 5,
+        "maxQueueSize": 1000,
+        "finalFlushOnStop": True
+    }
+}
 
 # Default bypass domains for macOS system proxy
 DEFAULT_BYPASS: list[str] = ["aq.jdtest.net", "aqapi.jdtest.local", "0.0.0.0", "::1"]
