@@ -159,6 +159,76 @@ def _run_admin_batch(commands: List[List[str]], prompt: str = None, title: str =
 def _helper_plist_path() -> str:
     return "/Library/LaunchDaemons/com.jdcat.proxy.helper.plist"
 
+def _detect_python_interpreter() -> str:
+    """
+    检测可用的Python3解释器路径，按优先级顺序返回第一个可用的路径。
+    优先级：系统默认 > Homebrew > 其他常见位置
+    """
+    python_candidates = [
+        "/usr/bin/python3",           # macOS系统默认
+        "/opt/homebrew/bin/python3",  # Apple Silicon Homebrew
+        "/usr/local/bin/python3",     # Intel Homebrew
+        "/Library/Frameworks/Python.framework/Versions/3.11/bin/python3",  # Python.org安装
+        "/Library/Frameworks/Python.framework/Versions/3.10/bin/python3",
+        "/Library/Frameworks/Python.framework/Versions/3.9/bin/python3",
+    ]
+    
+    for python_path in python_candidates:
+        if not os.path.exists(python_path):
+            continue
+        try:
+            # 验证Python解释器是否可执行且版本合适
+            result = subprocess.run([python_path, "--version"], 
+                                  capture_output=True, text=True, timeout=5)
+            if result.returncode == 0 and "Python 3." in result.stdout:
+                _logger.info("[python-detect] 找到可用Python解释器: %s (%s)", 
+                           python_path, result.stdout.strip())
+                return python_path
+        except Exception as e:
+            _logger.debug("[python-detect] Python路径检查失败 %s: %s", python_path, e)
+            continue
+    
+    # 如果没有找到，抛出错误
+    raise RuntimeError(f"未找到可用的Python3解释器。已检查路径: {python_candidates}")
+
+def _generate_dynamic_plist(python_path: str) -> str:
+    """
+    根据检测到的Python解释器路径生成动态plist内容
+    """
+    plist_template = '''<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+  <dict>
+    <key>Label</key>
+    <string>com.jdcat.proxy.helper</string>
+
+    <key>ProgramArguments</key>
+    <array>
+      <string>{python_path}</string>
+      <string>/Library/PrivilegedHelperTools/jdcat_proxy_helper.py</string>
+      <string>--port</string>
+      <string>17901</string>
+    </array>
+
+    <key>RunAtLoad</key>
+    <true/>
+
+    <key>KeepAlive</key>
+    <true/>
+
+    <key>UserName</key>
+    <string>root</string>
+
+    <!-- Optional logs for troubleshooting -->
+    <key>StandardOutPath</key>
+    <string>/var/log/com.jdcat.proxy.helper.out.log</string>
+    <key>StandardErrorPath</key>
+    <string>/var/log/com.jdcat.proxy.helper.err.log</string>
+  </dict>
+</plist>'''
+    
+    return plist_template.format(python_path=python_path)
+
 def _helper_healthcheck(timeout: float = 1.0) -> bool:
     try:
         req = _urlreq.Request(url="http://127.0.0.1:17901/health", method="GET")
@@ -179,12 +249,12 @@ def _helper_healthcheck(timeout: float = 1.0) -> bool:
 
 def install_if_needed() -> None:
     """
-    首次安装 Root Helper（仅在缺失或不可用时触发一次管理员弹窗）：
+    安装 Root Helper，支持智能重试机制：
       1) 创建目录 /Library/PrivilegedHelperTools
       2) 复制打包内 jdcat/root_helper/jdcat_proxy_helper.py -> /Library/PrivilegedHelperTools/jdcat_proxy_helper.py（chmod 0755, chown root:wheel）
       3) 复制打包内 jdcat/resources/com.jdcat.proxy.helper.plist -> /Library/LaunchDaemons/com.jdcat.proxy.helper.plist（chmod 0644, chown root:wheel）
       4) launchctl bootstrap/enable/kickstart
-    安装后不做二次安装尝试；仅在本函数内进行一次管理员弹窗。
+    首次安装失败时自动重试一次，以解决macOS LaunchDaemon时序问题。
     """
     global _helper_install_attempted_once
     _ensure_darwin()
@@ -202,6 +272,16 @@ def install_if_needed() -> None:
         _logger.info("[helper-install] 本轮已尝试安装，跳过重复安装与弹窗")
         return
     _helper_install_attempted_once = True
+    
+    # 执行安装
+    _logger.info("[helper-install] 开始安装...")
+    _perform_installation()
+
+def _perform_installation() -> None:
+    """
+    执行安装过程
+    """
+    
     # 计算打包内源文件路径（基于当前模块 __file__）
     here = os.path.abspath(os.path.dirname(__file__))
     pkg_root = os.path.abspath(os.path.join(here, ".."))  # jdcat/
@@ -363,10 +443,49 @@ def install_if_needed() -> None:
     # 步骤2：分步执行安装脚本，每步单独记录
     _logger.info("[helper-install] 步骤2 - 构建分步安装脚本")
     
+    # 检测可用的Python解释器路径
+    _logger.info("[helper-install] 检测可用的Python解释器...")
+    try:
+        python_path = _detect_python_interpreter()
+        _logger.info("[helper-install] 将使用Python解释器: %s", python_path)
+    except RuntimeError as e:
+        _logger.error("[helper-install] Python解释器检测失败: %s", e)
+        raise e
+    
+    # 生成动态plist内容
+    _logger.info("[helper-install] 生成适配的plist配置...")
+    dynamic_plist_content = _generate_dynamic_plist(python_path)
+    
+    # 创建临时plist文件用于安装
+    import tempfile
+    temp_plist_fd = None
+    temp_plist_path = None
+    try:
+        temp_plist_fd, temp_plist_path = tempfile.mkstemp(suffix='.plist', prefix='jdcat_helper_')
+        with os.fdopen(temp_plist_fd, 'w') as f:
+            f.write(dynamic_plist_content)
+        temp_plist_fd = None  # 已关闭
+        _logger.info("[helper-install] 临时plist文件已生成: %s", temp_plist_path)
+        
+        # 更新src_plist为动态生成的临时文件
+        src_plist = temp_plist_path
+        
+    except Exception as e:
+        if temp_plist_fd:
+            try:
+                os.close(temp_plist_fd)
+            except:
+                pass
+        _logger.error("[helper-install] 临时plist文件创建失败: %s", e)
+        raise RuntimeError(f"无法创建临时plist文件: {e}")
+    
     # 构建AppleScript兼容的单行脚本，避免多行语法错误
     # 分步执行安装，每步单独记录结果和错误
     steps = [
         f"/bin/launchctl bootout system/com.jdcat.proxy.helper 2>/dev/null || echo 'STEP1-OK: bootout完成'",
+        f"/bin/launchctl remove com.jdcat.proxy.helper 2>/dev/null || echo 'STEP1B-OK: remove完成'",
+        f"/bin/launchctl unload '{dst_plist}' 2>/dev/null || echo 'STEP1C-OK: unload完成'",
+        f"echo 'STEP1D-INFO: 等待清理完成...' && sleep 8",  # 简化为固定等待，避免AppleScript语法问题
         f"/bin/rm -f '{dst_plist}' '{dst_helper}' 2>/dev/null || echo 'STEP2-OK: 文件清理完成'",
         f"/bin/mkdir -p '/Library/PrivilegedHelperTools' && echo 'STEP3-OK: 目录创建成功' || echo 'STEP3-FAIL: 目录创建失败'",
         f"/bin/cp '{src_helper}' '{dst_helper}' && echo 'STEP4-OK: Helper复制成功' || echo 'STEP4-FAIL: Helper复制失败'",
@@ -404,6 +523,10 @@ def install_if_needed() -> None:
         if err:
             _logger.info("[helper-install] 标准错误:\n%s", err)
         
+        # 检查是否有bootstrap失败
+        bootstrap_failed = False
+        kickstart_failed = False
+        
         if code == 0:
             _logger.info("[helper-install] 诊断安装脚本执行成功")
             
@@ -413,6 +536,11 @@ def install_if_needed() -> None:
                 for line in lines:
                     if line.strip():
                         _logger.info("[helper-install] 步骤结果: %s", line.strip())
+                        # 检查关键步骤是否失败
+                        if "STEP13-FAIL: bootstrap失败" in line:
+                            bootstrap_failed = True
+                        if "STEP15-FAIL: kickstart失败" in line:
+                            kickstart_failed = True
         else:
             _logger.error("[helper-install] 诊断安装脚本执行失败，返回码: %s", code)
             
@@ -432,10 +560,74 @@ def install_if_needed() -> None:
             
             raise RuntimeError(f"Helper安装失败 - 详细诊断信息请查看日志: {error_output}")
         
+        # 如果bootstrap失败，尝试自动重试一次
+        if bootstrap_failed:
+            _logger.warning("[helper-install] Bootstrap首次失败，等待5秒后自动重试...")
+            time.sleep(5)  # 等待系统状态稳定
+            
+            # 构建重试的bootstrap和kickstart命令
+            retry_steps = [
+                f"echo 'RETRY-START: 开始重试bootstrap' && /bin/launchctl bootstrap system '{dst_plist}' && echo 'RETRY-BOOTSTRAP-OK: 重试bootstrap成功' || echo 'RETRY-BOOTSTRAP-FAIL: 重试bootstrap失败'",
+                f"/bin/launchctl enable system/com.jdcat.proxy.helper && echo 'RETRY-ENABLE-OK: 重试enable成功' || echo 'RETRY-ENABLE-FAIL: 重试enable失败'",
+                f"/bin/launchctl kickstart -k system/com.jdcat.proxy.helper && echo 'RETRY-KICKSTART-OK: 重试kickstart成功' || echo 'RETRY-KICKSTART-FAIL: 重试kickstart失败'"
+            ]
+            
+            retry_script = " && ".join(retry_steps)
+            retry_applescript = f'do shell script "{retry_script}" with administrator privileges with prompt "{escaped_prompt}"'
+            
+            _logger.info("[helper-install] 执行重试...")
+            
+            try:
+                retry_p = subprocess.run(["/usr/bin/osascript", "-e", retry_applescript], 
+                                       capture_output=True, text=True, timeout=30)
+                retry_out = (retry_p.stdout or "").strip()
+                retry_err = (retry_p.stderr or "").strip()
+                retry_code = int(retry_p.returncode or 0)
+                
+                _logger.info("[helper-install] 重试执行完成，返回码: %s", retry_code)
+                if retry_out:
+                    _logger.info("[helper-install] 重试输出:\n%s", retry_out)
+                
+                # 检查重试结果
+                retry_bootstrap_success = "RETRY-BOOTSTRAP-OK" in retry_out
+                
+                if retry_code == 0 and retry_bootstrap_success:
+                    _logger.info("[helper-install] ✅ 重试成功！Bootstrap已完成")
+                    bootstrap_failed = False  # 重置失败标记
+                else:
+                    _logger.error("[helper-install] ❌ 重试仍然失败")
+                    if retry_err:
+                        _logger.error("[helper-install] 重试错误: %s", retry_err)
+                    
+            except subprocess.TimeoutExpired:
+                _logger.error("[helper-install] 重试超时（30秒）")
+            except Exception as e:
+                _logger.error("[helper-install] 重试执行异常: %s", e)
+        
+        # 如果重试后仍然失败，则报错
+        if bootstrap_failed:
+            _logger.error("[helper-install] Bootstrap失败（包括重试），服务无法注册，停止后续检查")
+            raise RuntimeError("LaunchDaemon bootstrap失败（已重试） - 服务无法注册到系统，可能是系统繁忙或权限问题")
+        
     except subprocess.TimeoutExpired:
         _logger.error("[helper-install] 安装脚本执行超时（90秒）")
+        # 清理临时plist文件
+        if temp_plist_path and os.path.exists(temp_plist_path):
+            try:
+                os.unlink(temp_plist_path)
+                _logger.info("[helper-install] 临时plist文件已清理: %s", temp_plist_path)
+            except Exception as cleanup_e:
+                _logger.warning("[helper-install] 临时plist文件清理失败: %s", cleanup_e)
         raise RuntimeError("Helper安装超时（90秒）- 可能系统权限对话框未响应或安装过程较慢")
     except Exception as e:
+        # 清理临时plist文件
+        if temp_plist_path and os.path.exists(temp_plist_path):
+            try:
+                os.unlink(temp_plist_path)
+                _logger.info("[helper-install] 临时plist文件已清理: %s", temp_plist_path)
+            except Exception as cleanup_e:
+                _logger.warning("[helper-install] 临时plist文件清理失败: %s", cleanup_e)
+        
         if "用户已取消" in str(e) or "User canceled" in str(e):
             _logger.info("[helper-install] 用户取消了管理员授权")
             raise RuntimeError("用户取消了管理员授权")
@@ -443,8 +635,97 @@ def install_if_needed() -> None:
             _logger.error("[helper-install] 安装过程异常: %s", e)
             raise RuntimeError(f"Helper安装执行失败: {e}")
 
-    # 安装完成后：等待 Helper 启动并健康就绪（增加等待时间，因为LaunchDaemon首次启动较慢）
-    _logger.info("[helper-install] 安装完成，等待Helper服务启动...")
+    # 安装完成后：先确认LaunchDaemon状态，再进行健康检查
+    _logger.info("[helper-install] 安装完成，等待LaunchDaemon服务加载...")
+    
+    # 由于launchctl list检测不可靠，直接跳过LaunchDaemon状态检查
+    # 改为直接进行健康检查，这是更可靠的服务可用性检测方式
+    _logger.info("[helper-install] 跳过LaunchDaemon状态检查，直接进行服务健康检查...")
+    
+    _logger.info("[helper-install] 开始Helper服务健康检查...")
+    
+    # 诊断：检查LaunchDaemon状态和日志
+    _logger.info("[helper-install] 诊断 - 检查LaunchDaemon状态...")
+    try:
+        # 检查服务是否已加载
+        result = subprocess.run(["/bin/launchctl", "list", "com.jdcat.proxy.helper"],
+                               capture_output=True, text=True, timeout=5)
+        if result.returncode == 0:
+            _logger.info("[helper-install] 诊断 - 服务状态: %s", result.stdout.strip())
+        else:
+            _logger.warning("[helper-install] 诊断 - 服务未找到或未加载: %s", result.stderr.strip())
+        
+        # 检查系统日志中的相关错误
+        log_result = subprocess.run(["/usr/bin/log", "show", "--predicate", 
+                                   "process == 'launchd' AND eventMessage CONTAINS 'com.jdcat.proxy.helper'",
+                                   "--style", "syslog", "--last", "2m"],
+                                  capture_output=True, text=True, timeout=10)
+        if log_result.stdout.strip():
+            _logger.info("[helper-install] 诊断 - 系统日志: %s", log_result.stdout.strip())
+        
+        # 检查Helper服务的标准输出和错误日志
+        helper_logs = [
+            "/var/log/com.jdcat.proxy.helper.out.log",
+            "/var/log/com.jdcat.proxy.helper.err.log"
+        ]
+        for log_file in helper_logs:
+            if os.path.exists(log_file):
+                try:
+                    with open(log_file, 'r') as f:
+                        content = f.read().strip()
+                        if content:
+                            _logger.info("[helper-install] 诊断 - %s 内容: %s", log_file, content[-500:])  # 只显示最后500字符
+                        else:
+                            _logger.info("[helper-install] 诊断 - %s 为空", log_file)
+                except Exception as e:
+                    _logger.warning("[helper-install] 诊断 - 无法读取 %s: %s", log_file, e)
+            else:
+                _logger.info("[helper-install] 诊断 - %s 不存在", log_file)
+        
+        # 尝试验证Helper脚本的语法和导入
+        _logger.info("[helper-install] 诊断 - 验证Helper脚本语法...")
+        try:
+            # 使用python -m py_compile验证语法
+            syntax_check = subprocess.run([
+                python_path, "-m", "py_compile", "/Library/PrivilegedHelperTools/jdcat_proxy_helper.py"
+            ], capture_output=True, text=True, timeout=10)
+            
+            _logger.info("[helper-install] 诊断 - 语法检查结果: 返回码=%s", syntax_check.returncode)
+            if syntax_check.stderr:
+                _logger.info("[helper-install] 诊断 - 语法检查错误: %s", syntax_check.stderr.strip())
+                
+        except Exception as e:
+            _logger.warning("[helper-install] 诊断 - 语法检查失败: %s", e)
+        
+        # 尝试导入测试Helper脚本的依赖
+        _logger.info("[helper-install] 诊断 - 测试Python依赖...")
+        try:
+            import_test = subprocess.run([
+                python_path, "-c", 
+                "import json, logging, argparse, os, subprocess, sys; "
+                "from http.server import BaseHTTPRequestHandler, HTTPServer; "
+                "from socketserver import ThreadingMixIn; "
+                "print('依赖导入成功')"
+            ], capture_output=True, text=True, timeout=10)
+            
+            _logger.info("[helper-install] 诊断 - 依赖测试结果: 返回码=%s", import_test.returncode)
+            if import_test.stdout:
+                _logger.info("[helper-install] 诊断 - 依赖测试输出: %s", import_test.stdout.strip())
+            if import_test.stderr:
+                _logger.info("[helper-install] 诊断 - 依赖测试错误: %s", import_test.stderr.strip())
+                
+        except Exception as e:
+            _logger.warning("[helper-install] 诊断 - 依赖测试失败: %s", e)
+        
+        # 检查plist文件的实际内容
+        try:
+            with open(dst_plist, 'r') as f:
+                plist_content = f.read()
+        except Exception as e:
+            _logger.warning("[helper-install] 诊断 - 无法读取plist文件: %s", e)
+                
+    except Exception as e:
+        _logger.warning("[helper-install] 诊断 - 状态检查失败: %s", e)
     
     try:
         from . import root_helper_client as _rhc
@@ -453,26 +734,50 @@ def install_if_needed() -> None:
 
     wait_ok = False
     if _rhc and hasattr(_rhc, "wait_for_helper"):
-        # 增加超时时间到20秒，给LaunchDaemon足够启动时间
-        wait_ok = bool(_rhc.wait_for_helper(timeout=20.0, interval=0.5))
+        # 使用更长的超时时间，给LaunchDaemon足够启动时间
+        wait_ok = bool(_rhc.wait_for_helper(timeout=15.0, interval=2.0))
     else:
-        # 兼容：本地简单轮询，增加到40次检查（20秒）
-        _logger.info("[helper-install] 开始健康检查轮询...")
-        for i in range(40):
-            if _helper_healthcheck(timeout=0.6):
-                _logger.info("[helper-install] 健康检查成功，Helper在第%d次尝试后就绪", i + 1)
+        # 实现轮询健康检查：每2秒检查一次，15秒后失败
+        _logger.info("[helper-install] 开始健康检查轮询（每2秒检查一次，最多15秒）...")
+        max_checks = 8  # 8次 * 2秒 = 16秒（约15秒）
+        for i in range(max_checks):
+            check_time = (i + 1) * 2
+            _logger.info("[helper-install] 第%d/%d次健康检查（%d秒）...", i + 1, max_checks, check_time)
+            
+            if _helper_healthcheck(timeout=2.0):  # 增加单次检查超时时间
+                _logger.info("[helper-install] ✅ 健康检查成功！Helper服务在%d秒后就绪", check_time)
                 wait_ok = True
                 break
-            if i % 10 == 9:  # 每5秒记录一次进度
-                _logger.info("[helper-install] 健康检查进行中... (%d/40)", i + 1)
-            time.sleep(0.5)
+            
+            if i < max_checks - 1:  # 不是最后一次检查
+                _logger.info("[helper-install] ⏳ Helper服务尚未就绪，2秒后重试...")
+                time.sleep(2)
+            else:
+                _logger.warning("[helper-install] ❌ 健康检查超时，已尝试%d次（共%d秒）", max_checks, max_checks * 2)
 
     if not wait_ok:
-        _logger.error("[helper-install] Helper服务20秒内未能启动，可能需要更多时间")
-        _logger.error("[helper-install] 建议：稍后重试，或检查系统日志")
-        raise RuntimeError("Root Helper 安装后健康检查失败（/health 不可达）- LaunchDaemon可能需要更多启动时间")
+        _logger.error("[helper-install] Helper服务15秒内未能启动，服务可能存在问题")
+        _logger.error("[helper-install] 建议：检查系统日志或Helper服务日志文件")
+        
+        # 清理临时plist文件
+        if temp_plist_path and os.path.exists(temp_plist_path):
+            try:
+                os.unlink(temp_plist_path)
+                _logger.info("[helper-install] 临时plist文件已清理: %s", temp_plist_path)
+            except Exception as e:
+                _logger.warning("[helper-install] 临时plist文件清理失败: %s", e)
+        
+        raise RuntimeError("Root Helper 安装后健康检查失败（/health 不可达）- 服务在15秒内未能启动，可能存在配置或权限问题")
 
     _logger.info("[helper-install] 健康检查通过，Helper 就绪")
+    
+    # 清理临时plist文件
+    if temp_plist_path and os.path.exists(temp_plist_path):
+        try:
+            os.unlink(temp_plist_path)
+            _logger.info("[helper-install] 临时plist文件已清理: %s", temp_plist_path)
+        except Exception as e:
+            _logger.warning("[helper-install] 临时plist文件清理失败: %s", e)
 
 class NoActiveNetworkServices(Exception):
     """Raised when no active macOS network services are detected."""
