@@ -426,6 +426,23 @@ def modify_request_with_identity(original_request: Dict[str, Any], identity: Dic
         except Exception:
             mod_body = raw_text if raw_text is not None else body
 
+    # 6) 内部标记头保证：在统一头替换完成后进行最终注入，避免被覆盖
+    try:
+        present_non_empty = False
+        for k, v in list(mod_headers.items()):
+            if str(k).lower().strip() == "x-ss-internal":
+                if str(v).strip():
+                    present_non_empty = True
+                break
+        if not present_non_empty:
+            mod_headers["X-SS-Internal"] = "permission-test"
+            logger.info("[IDENTITY-REPLACE] inject_internal_hdr_at_source=true")
+        else:
+            logger.info("[IDENTITY-REPLACE] inject_internal_hdr_at_source=false")
+    except Exception:
+        # 忽略注入失败，由发送侧兜底
+        pass
+
     # 6) 返回结果 + 详细日志输出（对齐老工具格式，包含cookies）
     result = {
         "method": method,
